pywurfl

Package pywurfl |
[hide private]
[frames] | no frames]

# Package pywurfl

source code

pywurfl - Python tools for processing and querying the Wireless Universal Resource File (WURFL)

Version: 7.2.1

Author: Armand Lynch <lyncha@users.sourceforge.net>

Copyright: Copyright 2006-2011, Armand Lynch

License: LGPL

Submodules | [hide private]
pywurfl.algorithms: pywurfl search algorithms pywurfl.algorithms.wurfl pywurfl.algorithms.wurfl.handlers: This module contains the supporting classes for the Two Step Analysis user agent algorithm that is used as the primary way to match user agents with the Java API for the WURFL. pywurfl.algorithms.wurfl.normalizers: This module contains the supporting classes for the Two Step Analysis user agent algorithm that is used as the primary way to match user agents with the Java API for the WURFL. pywurfl.algorithms.wurfl.strategies: This module contains the supporting classes for the Two Step Analysis user agent algorithm that is used as the primary way to match user agents with the Java API for the WURFL. pywurfl.algorithms.wurfl.utils: This module contains the supporting classes for the Two Step Analysis user agent algorithm that is used as the primary way to match user agents with the Java API for the WURFL. pywurfl.exceptions: Exception Classes pywurfl.ql: pywurfl Query Language pywurfl.serialize: pywurfl WURFL class hierarchy serializer pywurfl.wurflprocessor: WURFL processing utility.

Classes | [hide private]
| RootDevice pywurfl Root Device base class.
| Devices Main pywurfl API class.

Functions | [hide private]
devclass(parent, devid, devua, actual_device_root, new_caps=None) Return a pywurfl.Device class. | source code
_unicode_check(name, val) | source code

Variables | [hide private]
| __doc__ = ``...``
| __contributors__ = ``'``Pau Aliagas <pau@newtral.org>``'``
| __url__ = ``'``http://celljam.net/``'``
| __package__ = ``'``pywurfl``'``

Function Details | [hide private]

### devclass(parent, devid, devua, actual_device_root, new_caps=None) | source code
Return a pywurfl.Device class. Parameters: `parent` (Device) - A Device class or None. `devid` (unicode) - The device id for the returned class. `devua` (unicode) - The user agent for the returned class. `actual_device_root` (boolean) - Whether or not the returned class is an actual device. `new_caps` (dict) - The new capabilities for the returned class.

Variables Details | [hide private]

  ### __doc__ Value:
      """
      pywurfl - Python tools for processing and querying the Wireless Univer
      sal Resource File (WURFL)
      """